@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::InsertBlock::FromModule;
 
-our $DATE = '2015-03-11'; # DATE
-our $VERSION = '0.03'; # VERSION
+our $DATE = '2015-03-21'; # DATE
+our $VERSION = '0.04'; # VERSION
 
 use 5.010001;
 use strict;
@@ -12,12 +12,12 @@ use Module::Path::More qw(module_path);
 use parent qw(Dist::Zilla::Plugin::InsertBlock);
 
 sub _insert_block {
-    my($self, $module, $name) = @_;
+    my($self, $module, $name, $target) = @_;
 
     my $file = module_path(module=>$module) or
         $self->log_fatal(["can't find path for module %s", $module]);
 
-    $self->SUPER::_insert_block($file, $name);
+    $self->SUPER::_insert_block($file, $name, $target);
 }
 
 __PACKAGE__->meta->make_immutable;
@@ -36,7 +36,7 @@ Dist::Zilla::Plugin::InsertBlock::FromModule - Insert a block of text from anoth
 
 =head1 VERSION
 
-This document describes version 0.03 of Dist::Zilla::Plugin::InsertBlock::FromModule (from Perl distribution Dist-Zilla-Plugin-InsertBlock), released on 2015-03-11.
+This document describes version 0.04 of Dist::Zilla::Plugin::InsertBlock::FromModule (from Perl distribution Dist-Zilla-Plugin-InsertBlock), released on 2015-03-21.
 
 =head1 SYNOPSIS
 
